@@ -21,6 +21,7 @@
  *******************************************************************************/
 
 #include "util/stacktrace.h"
+#include "util/argstream.h"
 
 CrashStackTrace gCrashStackTrace;
 
@@ -29,10 +30,10 @@ CrashStackTrace gCrashStackTrace;
 #include <QSplashScreen>
 
 #include <rshare.h>
+#include "gui/common/FilesDefs.h"
 #include "gui/FriendsDialog.h"
 #include "gui/GenCertDialog.h"
 #include "gui/MainWindow.h"
-#include "gui/MessengerWindow.h"
 #include "gui/NetworkDialog.h"
 #include "gui/NetworkView.h"
 #include "gui/QuickStartWizard.h"
@@ -41,6 +42,7 @@ CrashStackTrace gCrashStackTrace;
 #include "gui/StartDialog.h"
 #include "gui/chat/ChatDialog.h"
 #include "gui/connect/ConfCertDialog.h"
+#include "gui/common/AvatarDialog.h"
 #include "gui/common/Emoticons.h"
 #include "gui/FileTransfer/SearchDialog.h"
 #include "gui/FileTransfer/TransfersDialog.h"
@@ -51,8 +53,12 @@ CrashStackTrace gCrashStackTrace;
 #include "util/RsGxsUpdateBroadcast.h"
 #include "util/rsdir.h"
 #include "util/rstime.h"
+#include "retroshare/rsinit.h"
 
-#ifdef ENABLE_WEBUI
+#ifdef MESSENGER_WINDOW
+#include "gui/MessengerWindow.h"
+#endif
+#ifdef RS_WEBUI
 #	include "gui/settings/WebuiPage.h"
 #endif
 
@@ -132,7 +138,7 @@ static void displayWarningAboutDSAKeys()
 	msgBox.setInformativeText(QObject::tr("DSA keys are not yet supported by this version of RetroShare. All these nodes will be unusable. We're very sorry for that."));
 	msgBox.setStandardButtons(QMessageBox::Ok);
 	msgBox.setDefaultButton(QMessageBox::Ok);
-    msgBox.setWindowIcon(QIcon(":/icons/logo_128.png"));
+    msgBox.setWindowIcon(FilesDefs::getIconFromQtResourcePath(":/icons/logo_128.png"));
 
 	msgBox.exec();
 }
@@ -226,7 +232,34 @@ feenableexcept(FE_INVALID | FE_DIVBYZERO);
 
 	/* RetroShare Core Objects */
 	RsInit::InitRsConfig();
-	int initResult = RsInit::InitRetroShare(argc, argv);
+
+    RsConfigOptions conf;
+
+	argstream as(argc,argv);
+	as      >> option('s',"stderr"           ,conf.outStderr      ,"output to stderr instead of log file."    )
+	        >> option('u',"udp"              ,conf.udpListenerOnly,"Only listen to UDP."                      )
+	        >> parameter('c',"base-dir"      ,conf.optBaseDir     ,"directory", "Set base directory."                                         ,false)
+	        >> parameter('l',"log-file"      ,conf.logfname       ,"logfile"   ,"Set Log filename."                                           ,false)
+	        >> parameter('d',"debug-level"   ,conf.debugLevel     ,"level"     ,"Set debug level."                                            ,false)
+	        >> parameter('i',"ip-address"    ,conf.forcedInetAddress,"nnn.nnn.nnn.nnn", "Force IP address to use (if cannot be detected)."    ,false)
+	        >> parameter('p',"port"          ,conf.forcedPort     ,"port"      ,"Set listenning port to use."                                 ,false)
+	        >> parameter('o',"opmode"        ,conf.opModeStr      ,"opmode"    ,"Set Operating mode (Full, NoTurtle, Gaming, Minimal)."       ,false);
+#ifdef RS_JSONAPI
+	as      >> parameter('J', "jsonApiPort", conf.jsonApiPort, "jsonApiPort", "Enable JSON API on the specified port", false )
+	        >> parameter('P', "jsonApiBindAddress", conf.jsonApiBindAddress, "jsonApiBindAddress", "JSON API Bind Address.", false);
+#endif // ifdef RS_JSONAPI
+
+#ifdef LOCALNET_TESTING
+	as      >> parameter('R',"restrict-port" ,portRestrictions             ,"port1-port2","Apply port restriction"                   ,false);
+#endif // ifdef LOCALNET_TESTING
+
+#ifdef RS_AUTOLOGIN
+	as      >> option('a',"auto-login"       ,conf.autoLogin      ,"AutoLogin (Windows Only) + StartMinimised");
+#endif // ifdef RS_AUTOLOGIN
+
+    conf.main_executable_path = argv[0];
+
+	int initResult = RsInit::InitRetroShare(conf);
 
 	if(initResult == RS_INIT_NO_KEYRING)	// happens when we already have accounts, but no pgp key. This is when switching to the openpgp-sdk version.
 	{
@@ -239,7 +272,7 @@ feenableexcept(FE_INVALID | FE_DIVBYZERO);
 		msgBox.setInformativeText(QObject::tr("Choose between:<br><ul><li><b>Ok</b> to copy the existing keyring from gnupg (safest bet), or </li><li><b>Close without saving</b> to start fresh with an empty keyring (you will be asked to create a new PGP key to work with RetroShare, or import a previously saved pgp keypair). </li><li><b>Cancel</b> to quit and forge a keyring by yourself (needs some PGP skills)</li></ul>"));
 		msgBox.setStandardButtons(QMessageBox::Ok | QMessageBox::Discard | QMessageBox::Cancel);
 		msgBox.setDefaultButton(QMessageBox::Ok);
-        msgBox.setWindowIcon(QIcon(":/icons/logo_128.png"));
+        msgBox.setWindowIcon(FilesDefs::getIconFromQtResourcePath(":/icons/logo_128.png"));
 
 		int ret = msgBox.exec();
 
@@ -250,7 +283,7 @@ feenableexcept(FE_INVALID | FE_DIVBYZERO);
 			if(!RsAccounts::CopyGnuPGKeyrings())
 				return 0 ; 
 
-			initResult = RsInit::InitRetroShare(argc, argv);
+			initResult = RsInit::InitRetroShare(conf);
 
 			displayWarningAboutDSAKeys() ;
 
@@ -268,7 +301,7 @@ feenableexcept(FE_INVALID | FE_DIVBYZERO);
 		displayWarningAboutDSAKeys();
 
 		QMessageBox mb(QMessageBox::Critical, QObject::tr("RetroShare"), "", QMessageBox::Ok);
-        mb.setWindowIcon(QIcon(":/icons/logo_128.png"));
+        mb.setWindowIcon(FilesDefs::getIconFromQtResourcePath(":/icons/logo_128.png"));
 
 		switch (initResult) 
 		{
@@ -409,7 +442,7 @@ feenableexcept(FE_INVALID | FE_DIVBYZERO);
 		}
 	}
 
-	QSplashScreen splashScreen(QPixmap(":/images/logo/logo_splash.png")/* , Qt::WindowStaysOnTopHint*/);
+    QSplashScreen splashScreen(FilesDefs::getPixmapFromQtResourcePath(":/images/logo/logo_splash.png")/* , Qt::WindowStaysOnTopHint*/);
 
 	splashScreen.show();
 	splashScreen.showMessage(rshare.translate("SplashScreen", "Load configuration"), Qt::AlignHCenter | Qt::AlignBottom);
@@ -461,6 +494,7 @@ feenableexcept(FE_INVALID | FE_DIVBYZERO);
 	RsharePeerSettings::Create();
 
 	Emoticons::load();
+	AvatarDialog::load();
 
 	if (Settings->value(QString::fromUtf8("FirstRun"), true).toBool()) {
 		splashScreen.hide();
@@ -541,19 +575,14 @@ feenableexcept(FE_INVALID | FE_DIVBYZERO);
 
 	notify->enable() ;	// enable notification system after GUI creation, to avoid data races in Qt.
 
-#ifdef ENABLE_WEBUI
-    WebuiPage::checkStartWebui();
-#endif // ENABLE_WEBUI
-
 #ifdef RS_JSONAPI
 	JsonApiPage::checkStartJsonApi();
+
+#ifdef RS_WEBUI
+    WebuiPage::checkStartWebui();	// normally we should rather save the UI flags internally to p3webui
+#endif
 #endif // RS_JSONAPI
 
-	// This is done using a timer, because the passphrase request from notify is asynchrouneous and therefore clearing the
-	// passphrase here makes it request for a passphrase when creating the default chat identity.
-
-	QTimer::singleShot(10000, notify, SLOT(resetCachedPassphrases())) ;
-
 	/* dive into the endless loop */
 	int ti = rshare.exec();
 	delete w ;
@@ -562,10 +591,6 @@ feenableexcept(FE_INVALID | FE_DIVBYZERO);
 	JsonApiPage::checkShutdownJsonApi();
 #endif // RS_JSONAPI
 
-#ifdef ENABLE_WEBUI
-	WebuiPage::checkShutdownWebui();
-#endif // ENABLE_WEBUI
-
 	/* cleanup */
 	ChatDialog::cleanupChat();
 #ifdef RS_ENABLE_GXS
